@@ -247,10 +247,8 @@ class Discretizer(BaseEstimator, TransformerMixin):
             has_rare = list(frequencies[frequencies <= q_min_freq].index)
             if any(has_rare):
                 if self.verbose: print("\n---\n[Discretizer] Fitting Quantitative Features (that have rare values)")
-                print(has_rare)
 
                 rare_values_orders = {feature: order for feature, order in self.values_orders.items() if feature in has_rare}
-                print(rare_values_orders)
                 discretizer = ClosestDiscretizer(rare_values_orders, min_freq=q_min_freq, verbose=self.verbose)
                 discretizer.fit(Xc, y)
 
@@ -299,12 +297,15 @@ class GroupedListDiscretizer(BaseEstimator, TransformerMixin):
         # iterating over each feature
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [GroupedListDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
+            
+            # initial feature
+            arr_feature = Xc[feature].values
 
             order = self.values_orders.get(feature)  # récupération des groupes
             to_discard = [order.get(group) for group in order]  # identification des valeur à regrouper
             to_input = [Xc[feature].isin(discarded) for discarded in to_discard]  # identification des observations à regrouper
             to_keep = [n if self.output == float else group for n, group in enumerate(order)]  # récupération du groupe dans lequel regrouper
-            Xc[feature] = select(to_input, to_keep, default=Xc[feature])  # regroupement des valeurs peu fréquentes
+            Xc[feature] = select(to_input, to_keep, default=arr_feature)  # grouping modalities
 
         # converting to float
         if self.output == float:
@@ -350,10 +351,13 @@ class ChainedDiscretizer(GroupedListDiscretizer):
                 # identifying modalities which rarest values
                 to_keep = values[frequencies >= self.min_freq]
                 
+                # initial feature
+                arr_feature = Xc[feature].values
+
                 # grouping rare modalities
                 to_discard = [[value for value in order.get(group) if (not value in to_keep)] for group in order]  # identifying rare values
                 to_input = [Xc[feature].isin(discarded) for discarded in to_discard]  # identifying observation to input
-                Xc[feature] = select(to_input, to_input, default=Xc[feature])  # regroupement des naf peu fréquents
+                Xc[feature] = select(to_input, to_input, default=arr_feature)  # regroupement des naf peu fréquents
                 
                 # historizing in the feature's order
                 for discarded, kept in zip(to_discard, order):
@@ -425,7 +429,7 @@ class QuantileDiscretizer(BaseEstimator, TransformerMixin):
         # iterating over each feature
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [QuantileDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
-            
+
             nans = isna(X[feature])  # keeping track of nans
 
             # grouping values inside quantiles
@@ -480,21 +484,23 @@ class ClosestDiscretizer(BaseEstimator, TransformerMixin):
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [ClosestDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
 
-            # récupération de l'ordre des modalités
+            # accessing feature's modalities' order
             order = self.values_orders.get(feature)
 
             # imputation des valeurs inconnues le cas échéant
             unknowns = [value for value in X_c[feature].unique() if not any(is_equal(value, known) for known in order.values())]
             unknowns = [value for value in unknowns if notna(value)]  # suppression des NaNs
             if any(unknowns):
+                arr_fature = X_c[feature].values  # initial feature
                 to_input = [X_c[feature] == unknown for unknown in unknowns]  # identification des valeurs à regrouper
-                X_c[feature] = select(to_input, [self.default_values.get(feature)], default=X_c[feature])  # regroupement des valeurs
+                X_c[feature] = select(to_input, [self.default_values.get(feature)], default=arr_fature)  # regroupement des valeurs
                 warn(f"Unknown modalities provided for {feature}: {unknowns}")
 
             # grouping values inside groups of modalities
+            arr_fature = X_c[feature].values  # initial feature
             to_discard = [order.get(group) for group in order]  # identification des valeur à regrouper
             to_input = [X_c[feature].isin(discarded) for discarded in to_discard]  # identification des valeurs à regrouper
-            X_c[feature] = select(to_input, order, default=X_c[feature])  # regroupement des valeurs
+            X_c[feature] = select(to_input, order, default=arr_fature)  # regroupement des valeurs
 
         return X_c
 
@@ -563,8 +569,9 @@ class DefaultDiscretizer(BaseEstimator, TransformerMixin):
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [DefaultDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
 
-            # regroupement des valeurs
-            X_c[feature] = select([~X_c[feature].isin(self.to_keep.get(feature))], [self.default_value], default=X_c[feature])
+            # grouping modalities
+            arr_fature = X_c[feature].values  # initial feature
+            X_c[feature] = select([~X_c[feature].isin(self.to_keep.get(feature))], [self.default_value], default=arr_fature)
 
         return X_c
 
